// qtractorAbout.h
//
/****************************************************************************
   Copyright (C) 2005-2021, rncbc aka Rui Nuno Capela. All rights reserved.

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

*****************************************************************************/

#ifndef __qtractorAbout_h
#define __qtractorAbout_h

#include "config.h"

#define QTRACTOR_TITLE        PACKAGE_NAME

#define QTRACTOR_SUBTITLE     "An Audio/MIDI multi-track sequencer"
#define QTRACTOR_WEBSITE      "https://qtractor.org"
#define QTRACTOR_COPYRIGHT    "Copyright (C) 2005-2021 rncbc aka Rui Nuno Capela. All rights reserved."

#define QTRACTOR_DOMAIN       "rncbc.org"

#endif  // __qtractorAbout_h

// end of qtractorAbout.h

